@@ -1,21 +1,9 @@
-/***************************************************************************
- *   Copyright 2009 Chani Armitage <chani@kde.org>
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Chani Armitage <chani@kde.org>
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef PALAPELI_MOUSEINPUTBUTTON_H
 #define PALAPELI_MOUSEINPUTBUTTON_H
@@ -27,12 +15,14 @@ class QLabel;
 
 namespace Palapeli
 {
+	class FlatButton;
+
 	class MouseInputButton : public QPushButton
 	{
 		Q_OBJECT
 		public:
-			explicit MouseInputButton(QWidget* parent = 0);
-			QSize sizeHint() const Q_DECL_OVERRIDE;
+			explicit MouseInputButton(QWidget* parent = nullptr);
+			QSize sizeHint() const override;
 
 			///If unset, this button will not generate any wheel triggers.
 			bool isMouseAllowed() const;
@@ -43,7 +33,6 @@ namespace Palapeli
 			bool isNoButtonAllowed() const;
 			void setNoButtonAllowed(bool noButtonAllowed);
 			bool showClearButton() const;
-			void setShowClearButton(bool showClearButton);
 			///If set, a call to setTrigger() will not immediately change the trigger. Instead, the triggerRequest() signal will be fired, and the new trigger will be set only after confirmTrigger() has been called.
 			bool requiresValidation() const;
 			void setRequiresValidation(bool requiresValidation);
@@ -57,7 +46,7 @@ namespace Palapeli
 			void confirmTrigger(const Palapeli::Trigger& trigger);
 			void setTrigger(const Palapeli::Trigger& trigger);
 		protected:
-			bool event(QEvent* event) Q_DECL_OVERRIDE;
+			bool event(QEvent* event) override;
 		private:
 			void updateAppearance();
 			void applyTrigger(const Palapeli::Trigger& newTrigger);
@@ -65,7 +54,7 @@ namespace Palapeli
 
 			QLabel* m_iconLabel;
 			QLabel* m_mainLabel;
-			QLabel* m_clearButton;
+			FlatButton* m_clearButton;
 
 			Palapeli::Trigger m_trigger, m_stagedTrigger; ///< m_stagedTrigger is the trigger which has been set with setTrigger(), but which is still waiting to be confirmed with confirmTrigger().
 			bool m_mouseAllowed, m_wheelAllowed;
